from schema_registry.client.client import SchemaRegistryClient
from schema_registry.client import schema, errors

__all__ = ["SchemaRegistryClient"]
